==> qtjambi-qt3drender-6.5.0-sources.jar: io/qt/qt3d/render/QStencilOperation.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Specifies stencil operation</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html">Qt3DRender::QStencilOperation</a></p>
 */
public class QStencilOperation extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilOperation.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QStencilOperation(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QStencilOperation() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#QStencilOperation">Qt3DRender::QStencilOperation::QStencilOperation(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QStencilOperation(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QStencilOperation instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #back()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QStencilOperationArguments getBack() {
        return back();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#back-prop">Qt3DRender::QStencilOperation::back()const</a></p>
     */
    @QtPropertyReader(name="back")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QStencilOperationArguments back(){
        return back_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QStencilOperationArguments back_native_constfct(long __this__nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #front()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QStencilOperationArguments getFront() {
        return front();
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#front-prop">Qt3DRender::QStencilOperation::front()const</a></p>
     */
    @QtPropertyReader(name="front")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QStencilOperationArguments front(){
        return front_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QStencilOperationArguments front_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QStencilOperation(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QStencilOperation(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QStencilOperation instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.5.2-sources.jar: io/qt/qt3d/render/QStencilOperation.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Specifies stencil operation</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html">Qt3DRender::QStencilOperation</a></code></p>
 */
public class QStencilOperation extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilOperation.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QStencilOperation(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QStencilOperation() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#QStencilOperation">Qt3DRender::QStencilOperation::<wbr>QStencilOperation(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QStencilOperation(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QStencilOperation instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #back()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QStencilOperationArguments getBack() {
        return back();
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#back-prop">Qt3DRender::QStencilOperation::<wbr>back()const</a></code></p>
     */
    @QtPropertyReader(name="back")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QStencilOperationArguments back(){
        return back_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QStencilOperationArguments back_native_constfct(long __this__nativeId);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #front()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QStencilOperationArguments getFront() {
        return front();
    }
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qstenciloperation.html#front-prop">Qt3DRender::QStencilOperation::<wbr>front()const</a></code></p>
     */
    @QtPropertyReader(name="front")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QStencilOperationArguments front(){
        return front_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QStencilOperationArguments front_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QStencilOperation(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QStencilOperation(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QStencilOperation instance, QDeclarativeConstructor constructor);
    
}
